==> webkit2gtk_2.48.6.orig.tar.xz: webkitgtk-2.48.6/Source/WebCore/rendering/style/StyleGridItemData.cpp <==
/*
 * Copyright (C) 2012 Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "StyleGridItemData.h"

#include "RenderStyleDifference.h"
#include "RenderStyleInlines.h"

namespace WebCore {

DEFINE_ALLOCATOR_WITH_HEAP_IDENTIFIER(StyleGridItemData);

StyleGridItemData::StyleGridItemData()
    : gridColumnStart(RenderStyle::initialGridItemColumnStart())
    , gridColumnEnd(RenderStyle::initialGridItemColumnEnd())
    , gridRowStart(RenderStyle::initialGridItemRowStart())
    , gridRowEnd(RenderStyle::initialGridItemRowEnd())
{
}

inline StyleGridItemData::StyleGridItemData(const StyleGridItemData& o)
    : RefCounted<StyleGridItemData>()
    , gridColumnStart(o.gridColumnStart)
    , gridColumnEnd(o.gridColumnEnd)
    , gridRowStart(o.gridRowStart)
    , gridRowEnd(o.gridRowEnd)
{
}

Ref<StyleGridItemData> StyleGridItemData::copy() const
{
    return adoptRef(*new StyleGridItemData(*this));
}

#if !LOG_DISABLED
void StyleGridItemData::dumpDifferences(TextStream& ts, const StyleGridItemData& other) const
{
    LOG_IF_DIFFERENT(gridColumnStart);
    LOG_IF_DIFFERENT(gridColumnEnd);
    LOG_IF_DIFFERENT(gridRowStart);
    LOG_IF_DIFFERENT(gridRowEnd);
}
#endif

} // namespace WebCore

==> webkit2gtk_2.51.3.orig.tar.xz: webkitgtk-2.51.3/Source/WebCore/rendering/style/StyleGridItemData.cpp <==
/*
 * Copyright (C) 2012 Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "StyleGridItemData.h"

#include "RenderStyleDifference.h"
#include "RenderStyleInlines.h"

namespace WebCore {

DEFINE_ALLOCATOR_WITH_HEAP_IDENTIFIER(StyleGridItemData);

StyleGridItemData::StyleGridItemData()
    : gridItemColumnStart(RenderStyle::initialGridItemColumnStart())
    , gridItemColumnEnd(RenderStyle::initialGridItemColumnEnd())
    , gridItemRowStart(RenderStyle::initialGridItemRowStart())
    , gridItemRowEnd(RenderStyle::initialGridItemRowEnd())
{
}

inline StyleGridItemData::StyleGridItemData(const StyleGridItemData& o)
    : RefCounted<StyleGridItemData>()
    , gridItemColumnStart(o.gridItemColumnStart)
    , gridItemColumnEnd(o.gridItemColumnEnd)
    , gridItemRowStart(o.gridItemRowStart)
    , gridItemRowEnd(o.gridItemRowEnd)
{
}

Ref<StyleGridItemData> StyleGridItemData::copy() const
{
    return adoptRef(*new StyleGridItemData(*this));
}

#if !LOG_DISABLED
void StyleGridItemData::dumpDifferences(TextStream& ts, const StyleGridItemData& other) const
{
    LOG_IF_DIFFERENT(gridItemColumnStart);
    LOG_IF_DIFFERENT(gridItemColumnEnd);
    LOG_IF_DIFFERENT(gridItemRowStart);
    LOG_IF_DIFFERENT(gridItemRowEnd);
}
#endif

} // namespace WebCore
